==> spip_3.2.11.orig.tar.xz: plugins-dist/medias/lang/medias_gl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=gl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_ajouter_document' => 'Engadir un documento',
	'bouton_ajouter_image' => 'Engadir unha imaxe',
	'bouton_ajouter_image_document' => 'Engadir umha imaxe ou un documento',

	// D
	'double_clic_inserer_doc' => 'Faga dobre click para inserir este recurso no texto',

	// E
	'entree_dimensions' => 'Dimensións:',
	'entree_titre_document' => 'Título do documento:',
	'entree_titre_image' => 'Título da imaxe:',

	// I
	'image_tourner_180' => 'Rotación 180°',
	'image_tourner_droite' => 'Rotación 90° á dereita',
	'image_tourner_gauche' => 'Rotación 90° á esquerda',
	'info_document' => 'Documento',
	'info_document_indisponible' => 'Este documento non está dispoñible',
	'info_documents' => 'Documentos',
	'info_inclusion_directe' => 'Inclusión directa:',
	'info_inclusion_vignette' => 'Inclusión da viñeta:',
	'info_installer_tous_documents' => 'Instalar todos os documentos',
	'info_logo_max_taille' => 'Os logos deben obrigatoriamente ter menos de @maxi@ (este ficheiro ten @actuel@).',
	'info_portfolio' => 'cartafol',
	'info_referencer_doc_distant' => 'Referenciar un documento na internet :',
	'info_telecharger' => 'Cargar desde a súa computadora:',
	'item_autoriser_selectionner_date_en_ligne' => 'Permite seleccionar a data de cada documento',
	'item_non_autoriser_selectionner_date_en_ligne' => 'A data dos documentos resulta ser aquela que indica cano foi engadida no web',

	// T
	'texte_documents_joints' => 'Pode autorizar o acompañamento de documentos (textos, imaxes,
  multimedia, etc.) aos artigos e/ou aos temas. Estes ficheiros
  poden aparecer referidos no artigo ou mostrados por separado.<p>', # MODIF
	'texte_documents_joints_2' => 'Este axuste non impide a inserción de imaxes directamente nos artigos.', # MODIF
	'titre_documents_joints' => 'Documentos adxuntos',
	'tout_dossier_upload' => 'Todo o cartafol @upload@',

	// U
	'upload_fichier_zip' => 'Arquivo ZIP',
	'upload_fichier_zip_texte' => 'O ficheiro que pretende instalar é un arquivo Zip.',
	'upload_fichier_zip_texte2' => 'Este ficheiro pode ser :',
	'upload_limit' => 'Este ficheiro é demasiado grande para o servidor ; o tamaño máximo autorizado en <i>upload</i> é de @max@.',
	'upload_zip_conserver' => 'Conservar o arquivo tras a extracción', # MODIF
	'upload_zip_decompacter' => 'descomprímase e cada elemento que conteña que sexa instalado no web. Os ficheiros que serán instalados son :',
	'upload_zip_telquel' => 'instalado tal cal, dado que é un arquivo comprimido Zip ;',
	'upload_zip_titrer' => 'Titular consonte o patrón de nome dos ficheiros.'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_gl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=gl
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_ajouter_document' => 'Engadir un documento',
	'bouton_ajouter_image' => 'Engadir unha imaxe',
	'bouton_ajouter_image_document' => 'Engadir umha imaxe ou un documento',

	// D
	'double_clic_inserer_doc' => 'Faga dobre click para inserir este recurso no texto',

	// E
	'entree_dimensions' => 'Dimensións:',
	'entree_titre_document' => 'Título do documento:',
	'entree_titre_image' => 'Título da imaxe:',

	// I
	'image_tourner_180' => 'Rotación 180°',
	'image_tourner_droite' => 'Rotación 90° á dereita',
	'image_tourner_gauche' => 'Rotación 90° á esquerda',
	'info_document' => 'Documento',
	'info_document_indisponible' => 'Este documento non está dispoñible',
	'info_documents' => 'Documentos',
	'info_inclusion_directe' => 'Inclusión directa:',
	'info_inclusion_vignette' => 'Inclusión da viñeta:',
	'info_installer_tous_documents' => 'Instalar todos os documentos',
	'info_logo_max_taille' => 'Os logos deben obrigatoriamente ter menos de @maxi@ (este ficheiro ten @actuel@).',
	'info_portfolio' => 'cartafol',
	'info_referencer_doc_distant' => 'Referenciar un documento na internet :',
	'info_telecharger' => 'Cargar desde a súa computadora:',
	'item_autoriser_selectionner_date_en_ligne' => 'Permite seleccionar a data de cada documento',
	'item_non_autoriser_selectionner_date_en_ligne' => 'A data dos documentos resulta ser aquela que indica cano foi engadida no web',

	// T
	'texte_documents_joints' => 'Pode autorizar o acompañamento de documentos (textos, imaxes,
  multimedia, etc.) aos artigos e/ou aos temas. Estes ficheiros
  poden aparecer referidos no artigo ou mostrados por separado.<p>', # MODIF
	'texte_documents_joints_2' => 'Este axuste non impide a inserción de imaxes directamente nos artigos.', # MODIF
	'titre_documents_joints' => 'Documentos adxuntos',
	'tout_dossier_upload' => 'Todo o cartafol @upload@',

	// U
	'upload_fichier_zip' => 'Arquivo ZIP',
	'upload_fichier_zip_texte' => 'O ficheiro que pretende instalar é un arquivo Zip.',
	'upload_fichier_zip_texte2' => 'Este ficheiro pode ser :',
	'upload_limit' => 'Este ficheiro é demasiado grande para o servidor ; o tamaño máximo autorizado en <i>upload</i> é de @max@.',
	'upload_zip_conserver' => 'Conservar o arquivo tras a extracción', # MODIF
	'upload_zip_decompacter' => 'descomprímase e cada elemento que conteña que sexa instalado no web. Os ficheiros que serán instalados son :',
	'upload_zip_telquel' => 'instalado tal cal, dado que é un arquivo comprimido Zip ;',
	'upload_zip_titrer' => 'Titular consonte o patrón de nome dos ficheiros.',
];
